@@ -8,9 +8,9 @@ package org.eclipse.aether.connector.basic;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -282,8 +282,7 @@ final class PartialFile
                 catch ( IOException e )
                 {
                     lockFile.close();
-                    LOGGER.debug( "Cannot create resumable file {}: {}", partFile.getAbsolutePath(), e.getMessage(),
-                            e );
+                    LOGGER.debug( "Cannot create resumable file {}", partFile.getAbsolutePath(), e );
                     // fall through and try non-resumable/temporary file location
                 }
             }
