@@ -92,7 +92,7 @@ public final class DefaultServiceLocator
         Entry( Class<T> type )
         {
             this.type = requireNonNull( type, "service type cannot be null" );
-            providers = new LinkedHashSet<Object>( 8 );
+            providers = new LinkedHashSet<>( 8 );
         }
 
         public synchronized void setServices( T... services )
@@ -130,7 +130,7 @@ public final class DefaultServiceLocator
         {
             if ( instances == null )
             {
-                instances = new ArrayList<T>( providers.size() );
+                instances = new ArrayList<>( providers.size() );
                 for ( Object provider : providers )
                 {
                     T instance;
@@ -170,11 +170,7 @@ public final class DefaultServiceLocator
                 }
                 return instance;
             }
-            catch ( Exception e )
-            {
-                serviceCreationFailed( type, impl, e );
-            }
-            catch ( LinkageError e )
+            catch ( Exception | LinkageError e )
             {
                 serviceCreationFailed( type, impl, e );
             }
@@ -192,7 +188,7 @@ public final class DefaultServiceLocator
      */
     public DefaultServiceLocator()
     {
-        entries = new HashMap<Class<?>, Entry<?>>();
+        entries = new HashMap<>();
 
         addService( RepositorySystem.class, DefaultRepositorySystem.class );
         addService( ArtifactResolver.class, DefaultArtifactResolver.class );
@@ -224,7 +220,7 @@ public final class DefaultServiceLocator
         Entry<T> entry = (Entry<T>) entries.get( requireNonNull( type, "service type cannot be null" ) );
         if ( entry == null && create )
         {
-            entry = new Entry<T>( type );
+            entry = new Entry<>( type );
             entries.put( type, entry );
         }
         return entry;
