@@ -8,9 +8,9 @@ package org.eclipse.aether.internal.impl;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -48,7 +48,7 @@ public final class DefaultRepositoryLayoutProvider
 
     private static final Logger LOGGER = LoggerFactory.getLogger( DefaultRepositoryLayoutProvider.class );
 
-    private Collection<RepositoryLayoutFactory> factories = new ArrayList<RepositoryLayoutFactory>();
+    private Collection<RepositoryLayoutFactory> factories = new ArrayList<>();
 
     public DefaultRepositoryLayoutProvider()
     {
@@ -76,7 +76,7 @@ public final class DefaultRepositoryLayoutProvider
     {
         if ( factories == null )
         {
-            this.factories = new ArrayList<RepositoryLayoutFactory>();
+            this.factories = new ArrayList<>();
         }
         else
         {
@@ -90,20 +90,18 @@ public final class DefaultRepositoryLayoutProvider
     {
         requireNonNull( repository, "remote repository cannot be null" );
 
-        PrioritizedComponents<RepositoryLayoutFactory> factories =
-            new PrioritizedComponents<RepositoryLayoutFactory>( session );
+        PrioritizedComponents<RepositoryLayoutFactory> factories = new PrioritizedComponents<>( session );
         for ( RepositoryLayoutFactory factory : this.factories )
         {
             factories.add( factory, factory.getPriority() );
         }
 
-        List<NoRepositoryLayoutException> errors = new ArrayList<NoRepositoryLayoutException>();
+        List<NoRepositoryLayoutException> errors = new ArrayList<>();
         for ( PrioritizedComponent<RepositoryLayoutFactory> factory : factories.getEnabled() )
         {
             try
             {
-                RepositoryLayout layout = factory.getComponent().newInstance( session, repository );
-                return layout;
+                return factory.getComponent().newInstance( session, repository );
             }
             catch ( NoRepositoryLayoutException e )
             {
@@ -113,10 +111,9 @@ public final class DefaultRepositoryLayoutProvider
         }
         if ( LOGGER.isDebugEnabled() && errors.size() > 1 )
         {
-            String msg = "Could not obtain layout factory for " + repository;
             for ( Exception e : errors )
             {
-                LOGGER.debug( msg, e );
+                LOGGER.debug( "Could not obtain layout factory for {}", repository, e );
             }
         }
 
