@@ -77,7 +77,8 @@ public class PlexusWagonConfigurator
         }
         else
         {
-            throw new IllegalArgumentException( "unexpected configuration type: " + configuration.getClass().getName() );
+            throw new IllegalArgumentException( "unexpected configuration type: "
+                    + configuration.getClass().getName() );
         }
 
         WagonComponentConfigurator configurator = new WagonComponentConfigurator();
